/**
 * \file tawConventionalConfig.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Tube and Wing Conventional Config source file
 * \version 0.1
 * \date 2023-11-24
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "t_tail_empennage_design_config.h"

namespace taw {
namespace low {

T_Tail_Config::T_Tail_Config()
    : design_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/design_mode")),
      mass_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/mass_mode")),
      vertical_stabilizer(TailElement(
          "module_configuration_file/program_settings/tube_and_wing/low_fidelity/t_tail/tail_element@0/")),
      horizontal_stabilizer(TailElement(
          "module_configuration_file/program_settings/tube_and_wing/low_fidelity/t_tail/tail_element@1/")),
      common_airfoil_data_path(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/common_airfoil_data_path")) {}

void T_Tail_Config::read(const node& xml) {
  design_mode.read(xml);
  mass_mode.read(xml);
  common_airfoil_data_path.read(xml);
  vertical_stabilizer.read(xml);
  horizontal_stabilizer.read(xml);
}

}  // namespace low
}  // namespace taw
