/**
 * \file T_TAILData.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief
 * \version 0.1
 * \date 2023-11-10
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef EMPENNAGEDESIGN_SRC_TAW_T_TAIL_T_TAILEMPENNAGEDESIGNDATA_H_
#define EMPENNAGEDESIGN_SRC_TAW_T_TAIL_T_TAILEMPENNAGEDESIGNDATA_H_

#include <aircraftGeometry2/geometry/factory.h>
#include <aircraftGeometry2/io/convert.h>

#include "lib/IO_methods/massPropertiesIO.h"
#include "lib/IO_methods/positionIO.h"
namespace taw
{
  namespace low
  {

    class T_Tail_Data
    {
    public:
      T_Tail_Data();

      void read(const node &xml);
      void read_wing(std::filesystem::path path, std::filesystem::path airfoil_data_dir);
      void read_fuselage(std::filesystem::path path, std::filesystem::path geometry_data_dir);

      void update(node &xml);
      void update_vertical_stabilizer(node &xml);
      void update_vertical_stabilizer_spars(node &xml);
      void update_vertical_stabilizer_control_devices(node &xml);

      void update_horizontal_stabilizer(node &xml);
      void update_horizontal_stabilizer_spars(node &xml);
      void update_horizontal_stabilizer_control_devices(node &xml);

      EndnodeReadOnly<double> maximum_takeoff_mass;
      EndnodeReadOnly<double> wing_position_x;

      geom2::MultisectionSurface<geom2::PolygonSection> fuselage;
      geom2::MultisectionSurface<geom2::AirfoilSection> wing;
      geom2::MultisectionSurface<geom2::AirfoilSection> vertical_stabilizer;
      std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> vertical_stabilizer_spars;
      std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> vertical_stabilizer_control_devices;
      std::vector<std::tuple<double,double>> vertical_stabilizer_control_devices_deflections;

      geom2::MultisectionSurface<geom2::AirfoilSection> horizontal_stabilizer;
      std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> horizontal_stabilizer_spars;
      std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> horizontal_stabilizer_control_devices;
      std::vector<std::tuple<double,double>> horizontal_stabilizer_control_devices_deflections;

      MassPropertiesIO vertical_stabilizer_mass;
      MassPropertiesIO horizontal_stabilizer_mass;
      MassPropertiesIO empennage_mass;
      PositionIO empennage_position;
    };

  } // namespace low
} // namespace taw
#endif // EMPENNAGEDESIGN_SRC_TAW_T_TAIL_T_TAILEMPENNAGEDESIGNDATA_H_
